"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SegmentedControl = void 0;

var _segmentedControl = _interopRequireDefault(require("@react-native-segmented-control/segmented-control"));

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * Default iOS control. Props are passed down to the original [SegmentedControl](https://github.com/react-native-segmented-control/segmented-control#react-native-segmented-controlsegmented-control).
 *
 * Example usage:
 *
 * ```tsx
 * import {
 *  Segmented,
 *  SegmentedControl
 * } from 'react-native-collapsible-segmented-view
 *
 * ...
 *
 * <Segmented.View
 *  control={(props) => <SegmentedControl {...props} appearence='dark' />}
 * >
 *  ...
 * ```
 */
const SegmentedControl = ({
  initialIndex,
  setIndex,
  labels,
  containerStyle,
  ...rest
}) => {
  const [selectedIndex, setSelectedIndex] = _react.default.useState(initialIndex);

  const onChange = _react.default.useCallback(event => {
    setIndex(event.nativeEvent.selectedSegmentIndex);
  }, [setIndex]);

  const onValueChange = _react.default.useCallback(label => {
    const nextIndex = labels.findIndex(l => l === label);
    setIndex(nextIndex);
    setSelectedIndex(nextIndex);
  }, [setIndex, labels]);

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, containerStyle]
  }, /*#__PURE__*/_react.default.createElement(_segmentedControl.default, _extends({
    values: labels,
    onChange: _helpers.IS_IOS ? onChange : undefined,
    onValueChange: _helpers.IS_IOS ? undefined : onValueChange,
    selectedIndex: selectedIndex
  }, rest)));
};

exports.SegmentedControl = SegmentedControl;

const styles = _reactNative.StyleSheet.create({
  container: {
    padding: 8
  }
});
//# sourceMappingURL=SegmentedControl.js.map