"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useIsFocused = useIsFocused;

var _react = _interopRequireDefault(require("react"));

var _SegmentContext = require("./SegmentContext");

var _SegmentedViewContext = require("./SegmentedViewContext");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *
 * Returns true if the segment is focused, else returns false
 *
 * @returns boolean
 */
function useIsFocused() {
  const {
    index,
    trackIndex
  } = (0, _SegmentedViewContext.useSegmentedViewContext)();
  const {
    index: segmentIndex
  } = (0, _SegmentContext.useSegmentContext)();

  const trackIsFocused = _react.default.useRef(trackIndex.current === segmentIndex);

  const [isFocused, setIsFocused] = _react.default.useState(trackIsFocused.current);

  _react.default.useEffect(() => {
    const listener = index.addListener(({
      value
    }) => {
      if (value === segmentIndex && !trackIsFocused.current || value !== segmentIndex && trackIsFocused.current) {
        trackIsFocused.current = !trackIsFocused.current;
        setIsFocused(trackIsFocused.current);
      }
    });
    return () => {
      index.removeListener(listener);
    };
  }, [index, segmentIndex]);

  return isFocused;
}
//# sourceMappingURL=useIsFocused.js.map