"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSelectedIndex = useSelectedIndex;

var _react = _interopRequireDefault(require("react"));

var _SegmentContext = require("./SegmentContext");

var _SegmentedViewContext = require("./SegmentedViewContext");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *
 * Returns the current segment selected index
 *
 * @returns number
 */
function useSelectedIndex() {
  const {
    index,
    trackIndex
  } = (0, _SegmentedViewContext.useSegmentedViewContext)();
  const {
    index: segmentIndex
  } = (0, _SegmentContext.useSegmentContext)();

  const trackSelectedIndex = _react.default.useRef(trackIndex.current);

  const [selectedIndex, setSelectedIndex] = _react.default.useState(trackSelectedIndex.current);

  _react.default.useEffect(() => {
    const listener = index.addListener(({
      value
    }) => {
      if (value !== trackSelectedIndex.current) {
        trackSelectedIndex.current = value;
        setSelectedIndex(trackIndex.current);
      }
    });
    return () => {
      index.removeListener(listener);
    };
  }, [index, segmentIndex, trackIndex]);

  return selectedIndex;
}
//# sourceMappingURL=useSelectedIndex.js.map